/********************************************************************************************************
 * @file     app_config.h
 *
 * @brief    for TLSR chips
 *
 * @author	 public@telink-semi.com;
 * @date     Sep. 18, 2018
 *
 * @par      Copyright (c) Telink Semiconductor (Shanghai) Co., Ltd.
 *           All rights reserved.
 *
 *			 The information contained herein is confidential and proprietary property of Telink
 * 		     Semiconductor (Shanghai) Co., Ltd. and is available under the terms
 *			 of Commercial License Agreement between Telink Semiconductor (Shanghai)
 *			 Co., Ltd. and the licensee in separate contract or the terms described here-in.
 *           This heading MUST NOT be removed from this file.
 *
 * 			 Licensees are granted free, non-transferable use of the information in this
 *			 file under Mutual Non-Disclosure Agreement. NO WARRENTY of ANY KIND is provided.
 *
 *******************************************************************************************************/

#pragma once

/* Enable C linkage for C++ Compilers: */
#if defined(__cplusplus)
extern "C" {
#endif

#define STRING_VENDOR           L"Telink"
#define STRING_PRODUCT          L"Homekit Accessory"
#define STRING_SERIAL           L"TLSR825x"		//8258

#define CHIP_TYPE               CHIP_TYPE_8258

/////////////////// FEATURE SELECT /////////////////////////////////
#define BLE_APP_PM_ENABLE					0
#define PM_DEEPSLEEP_RETENTION_ENABLE		0
#define BLE_REMOTE_SECURITY_ENABLE      	0
#define HK_SALTCHAR_RANDOM_FOR_SRP_ENABLE	1
#define HK_TEST_CASE_SIMULATE_ENABLE		0	//only for test case simulate operation.

#if HK_SALTCHAR_RANDOM_FOR_SRP_ENABLE
#define HK_DIFF_SRP_IN_PAIR_SETUP_ENABLE		1	//for TCH084
#else
#define HK_DIFF_SRP_IN_PAIR_SETUP_ENABLE		0
#endif

#define UART_PRINT_DEBUG_ENABLE				0


/////////////////// Clock  /////////////////////////////////
#define CLOCK_SYS_CLOCK_HZ  	48000000

enum{
	CLOCK_SYS_CLOCK_1S = CLOCK_SYS_CLOCK_HZ / 3,
	CLOCK_SYS_CLOCK_1MS = (CLOCK_SYS_CLOCK_1S / 1000),
	CLOCK_SYS_CLOCK_1US = (CLOCK_SYS_CLOCK_1S / 1000000),
};



/////////////////// watchdog  //////////////////////////////
#define MODULE_WATCHDOG_ENABLE		0
#define WATCHDOG_INIT_TIMEOUT		500  //ms



/////////////////// uart print /////////////////////////////////////
#if( UART_PRINT_DEBUG_ENABLE )
#define DEBUG_INFO_TX_PIN					GPIO_PC7
#define PRINT_BAUD_RATE						1000000

#define	PC7_FUNC							AS_GPIO
#define PC7_INPUT_ENABLE					0
#define PC7_OUTPUT_ENABLE					1
#define	PULL_WAKEUP_SRC_PC7					PM_PIN_PULLUP_1M
#define PC7_DATA_OUT						1
#endif


///////////////////// MFI Enable //////////////////////////
#if MFI_ENABLE          // for 8258 EVK with MFi
    #define PIN_MFI_I2C_RST     	GPIO_PA2
    #define PD1_FUNC                AS_GPIO
    #define PD1_INPUT_ENABLE        0
    #define PD1_OUTPUT_ENABLE       1
    #define PD1_DATA_STRENGTH       1
    #define PD1_DATA_OUT            1
    #define PULL_WAKEUP_SRC_PD1     PM_PIN_PULLUP_10K

    #define PIN_I2C_SDA         	GPIO_PA4
    #define PA3_FUNC                AS_GPIO
    #define PA3_INPUT_ENABLE        1
    #define PA3_OUTPUT_ENABLE       1
    #define PA3_DATA_STRENGTH       1
    #define PA3_DATA_OUT            1
    #define PULL_WAKEUP_SRC_PA3     PM_PIN_PULLUP_10K

    #define PIN_I2C_SCL         	GPIO_PA3
    #define PA4_FUNC                AS_GPIO
    #define PA4_INPUT_ENABLE        0
    #define PA4_OUTPUT_ENABLE       1
    #define PA4_DATA_STRENGTH       1
    #define PA4_DATA_OUT            1
    #define PULL_WAKEUP_SRC_PA4     PM_PIN_PULLUP_10K
#endif  //MFI_ENABLE

/////////////////// Flash Layout ///////////////////////////
#define FLASH_SECTOR_SIZE       (4096)

typedef volatile struct{
    volatile unsigned char * flash_adr_mac_111;
    volatile unsigned char * flash_adr_setupcode_111;
    //volatile unsigned char * flash_adr_pairing_111;
    volatile unsigned char * flash_adr_hash_id_111;
    volatile unsigned char * flash_adr_setup_id_111;
	volatile unsigned char * flash_adr_srpkey2_111;
	volatile unsigned char * flash_adr_srpkey2_crc_111;
}homkit_flash_parameter_layout_def;

#define FLASH_ADR_CHAR_VALUE        	0x68000
#define FLASH_ADR_SW_UUID				0x69000
#define FLASH_ADR_SW_TOKEN				0x6A000
#define FLASH_ADR_DEVICE_ID         	0x6B000
#define FLASH_ADR_HASH_ID           	0x6C000
#define FLASH_ADR_SETUPCODE         	0x6D000
#define FLASH_ADR_SETUPCODE_WRITE_CNT	0x6D004
#define FLASH_ADR_SETUPCODE_READ_CNT	0x6D008
#define FLASH_ADR_SETUP_ID				0x6E000
#define FLASH_ADR_SERIAL_NUMBER     	0x6F000


#define FLASH_ADR_ACCESSORY_LTSK		0x70000
#define FLASH_ADR_SRP_KEY           	0x71000
//#define FLASH_ADR_SRP_BOOTINIT_END  	0x71E00
#define FLASH_ADR_SRP_KEY_CRC_DATA		0x71E00
#define FLASH_ADR_ID_INFO           	0x72000
#define FLASH_ADR_FACTORY_RESET_CNT 	0x74000
#define FLASH_ADR_GLOBAL_STATE      	0x75000
#define FLASH_ADR_MAC               	0x76000
#define FLASH_ADR_DC                	0x77000
#define FLASH_ADR_TP_LOW            	0x77040
#define FLASH_ADR_TP_HIGH           	0x77041
//--#define FLASH_ADR_CHAR_VALUE        0x78000
//--#define FLASH_ADR_DEV_GRP_ADR       0x79000
#define FLASH_ADR_FW_UPDATE_CNT     	0x7A000
#define FLASH_ADR_ADV_ENCRYPTION_KEY    0x7B000
#define FLASH_ADR_NEW_ID            	0x7C000
#define FLASH_ADR_BROADCAST_GSN     	0x7D000
//#define FLASH_ADR_PAIRING           	0x7E000
//#define FLASH_ADR_OTA_READY_FLAG    	0x7F000
#define FLASH_ADR_SRP_KEY2           	0x7E000
#define FLASH_ADR_SRP_KEY2_CRC_DATA		0x7EE00
#define FLASH_ADR_SALTCHAR				0x7F000

#define FLASH_FLAG_VALID            	0x3132
#define VENDOR_ID                   	0x0211
#define FLASH_ADR_UPDATE_NEW_FW     	0x40000
#define ERASE_SECTORS_FOR_OTA      		48

//#define HOMEKIT_INITIAL_END_FLAG        "HOMEKIT_INITIAL!"
//#define HOMEKIT_INITIAL_END_FLAG_LEN    16  /* the lenght of striing defined by HOMEKIT_INITIAL_END_FLAG. */

#define OTA_PROGRAM_SIZE            		(160*1024)


// === HAP AUTH CHIP VERSION ===
#define MFI_AUTH_2_0_C						1	//MFI2.0C
#define MFI_AUTH_3_0						2	//MFI3.0

#if (MFI_ENABLE == 0x22)
#define MFI_AUTH_CHIP_VER					MFI_AUTH_2_0_C
#elif (MFI_ENABLE == 0x20)
#define MFI_AUTH_CHIP_VER					MFI_AUTH_3_0
#else
#define MFI_AUTH_CHIP_VER					0
#endif

#ifndef SOFTWARE_AUTHENTICATION_ENABLE
	#define SOFTWARE_AUTHENTICATION_ENABLE		0
#endif


/////////////////// BOARD PINs Define ////////////////////////////

#define BOARD_8267DONGLE_C1T82A3_V1_0   	1
#define BOARD_8267DONGLE_C1T82A3_V1_1   	2
#define BOARD_8267EVK_C1T80A30_V1_0     	3
#define BOARD_8267EVK_C1T80A30_V1_1     	4
#define BOARD_8269EVK_C1T80A30_V1_0			5	//only for 8269.
#define BOARD_8258EVK_C1T139A30_V1_2		6	//8258 EVK C1T139A30_V1.2.
#define BOARD_CUST_VERSION_1            	51
#define BOARD_CUST_VERSION_2            	52
#define BOARD_CUST_VERSION_3            	53
#define BOARD_CUST_VERSION_4            	54
#define BOARD_CUST_VERSION_5            	55
#define BOARD_CUST_VERSION_6            	56

//////////				 Select Support Board, here!	////////
#define BOARD_DEF       BOARD_8258EVK_C1T139A30_V1_2

#if(BOARD_DEF == BOARD_8258EVK_C1T139A30_V1_2)
// note !!!DEVICE_SHORT_NAME max 7 bytes for iOS9/iOS10
#define DEVICE_SHORT_NAME   	"R1x 0123456789"
#define DEVICE_FULL_NAME    	"R1x EVK SDK 20191030"

// For 8258 EVK
#define PWMID_R             	PWM0_ID                   // pwm0
#define PWM_R               	GPIO_PD5            // LED4, pwm0
#define PMW_MODE_R				AS_PWM0
#define PD5_FUNC                AS_GPIO//AS_PWM0
#define PD5_INPUT_ENABLE        0
#define PD5_OUTPUT_ENABLE       1
#define PD5_DATA_STRENGTH       0
#define PD5_DATA_OUT            0
#define PULL_WAKEUP_SRC_PD5     PM_PIN_PULLUP_1M

#define PWMID_B             	PWM3_ID                   // pwm3
#define PWM_B               	GPIO_PD2            // LED2, pwm3
#define PMW_MODE_B				AS_PWM3
#define PD2_FUNC                AS_GPIO//AS_PWM3
#define PD2_INPUT_ENABLE        0
#define PD2_OUTPUT_ENABLE       1
#define PD2_DATA_STRENGTH       0
#define PD2_DATA_OUT            0
#define PULL_WAKEUP_SRC_PD2     PM_PIN_PULLUP_1M

#define PWMID_G             	PWM1_ID                   // pwm1_N
#define PWM_G               	GPIO_PD3            // LED3, pwm1_N
#define PMW_MODE_G				AS_PWM1_N
#define PD3_FUNC                AS_GPIO//AS_PWM1_N
#define PD3_INPUT_ENABLE        0
#define PD3_OUTPUT_ENABLE       1
#define PD3_DATA_STRENGTH       0
#define PD3_DATA_OUT            0
#define PULL_WAKEUP_SRC_PD3     PM_PIN_PULLUP_1M

#define PWMID_W             	PWM2_ID                   // pwm2_N, share with YELLOW LED
#define PWM_W               	GPIO_PD4            // LED1, pwm2_N
#define PMW_MODE_W				AS_PWM2_N
#define PD4_FUNC                AS_GPIO//AS_PWM2_N
#define PD4_INPUT_ENABLE        0
#define PD4_OUTPUT_ENABLE       1
#define PD4_DATA_STRENGTH       0
#define PD4_DATA_OUT            0
#define PULL_WAKEUP_SRC_PD4     PM_PIN_PULLUP_1M

#define PWMID_Y             	PWM2_ID             // pwm2, share with WHITE LED
#define PWM_Y               	GPIO_PD4            // LED1, pwm2
#define PMW_MODE_Y				AS_PWM2_N
#define PD4_FUNC                AS_GPIO//AS_PWM2_N
#define PD4_INPUT_ENABLE        0
#define PD4_OUTPUT_ENABLE       1
#define PD4_DATA_STRENGTH       0
#define PD4_DATA_OUT            0
#define PULL_WAKEUP_SRC_PD4     PM_PIN_PULLUP_1M


#define	BUTTON_SW2_SW3_BASE		GPIO_PB2
#define PB2_FUNC                AS_GPIO
#define PB2_INPUT_ENABLE        0
#define PB2_OUTPUT_ENABLE       1
#define PB2_DATA_STRENGTH       0
#define PB2_DATA_OUT            0
#define PULL_WAKEUP_SRC_PB2     PM_PIN_PULLDOWN_100K


#define	BUTTON_SW4_SW5_BASE		GPIO_PB3
#define PB3_FUNC                AS_GPIO
#define PB3_INPUT_ENABLE        0
#define PB3_OUTPUT_ENABLE       1
#define PB3_DATA_STRENGTH       0
#define PB3_DATA_OUT            0
#define PULL_WAKEUP_SRC_PB3     PM_PIN_PULLDOWN_100K


#define	BUTTON_SW2_SW4_PIN		GPIO_PB4
#define PB4_FUNC                AS_GPIO
#define PB4_INPUT_ENABLE        1
#define PB4_OUTPUT_ENABLE       0
#define PB4_DATA_STRENGTH       0
#define PB4_DATA_OUT            0
#define PULL_WAKEUP_SRC_PB4     PM_PIN_PULLUP_10K


#define	BUTTON_SW3_SW5_PIN		GPIO_PB5
#define PB5_FUNC                AS_GPIO
#define PB5_INPUT_ENABLE        1
#define PB5_OUTPUT_ENABLE       0
#define PB5_DATA_STRENGTH       0
#define PB5_DATA_OUT            0
#define PULL_WAKEUP_SRC_PB5     PM_PIN_PULLUP_10K

//#define PM_GPIO_WAKEUP_PIN          BUTTON_ON           // set gpio wakeup pin. GPIO_PD3 is an alternative pin of EVK board for gpio wakeup
//#define PM_GPIO_WAKEUP_PIN_PULLUP   PM_PIN_PULLUP_10K   // set internal pullup resister of the gpio wakeup pin

#define PAUSE_KEY()   while (((gpio_read(BUTTON_ON)))&&((gpio_read(BUTTON_OFF))))

#endif



///////////////////////////////////// ATT  HANDLER define ///////////////////////////////////////
typedef enum
{
	ATT_H_START = 0,

	ATT_END_H,

}ATT_HANDLE;


#include "../common/default_config.h"

enum{
    CHAR_SAVE_FLAG = 0x15,
};

/* Disable C linkage for C++ Compilers: */
#if defined(__cplusplus)
}
#endif
